package Catalyst::Plugin::AutoCRUD::Model::DBIC;
BEGIN {
  $Catalyst::Plugin::AutoCRUD::Model::DBIC::VERSION = '1.112770';
}

use strict;
use warnings FATAL => 'all';

use base 'Catalyst::Model::DBIC::Schema';

1;
__END__
